###############################################################################
#                                                                             #
#   Reproducible files to 'Random Forests for Ordinal Response Data' (2014)   #
#   by Janitza, Tutz and Boulesteix                                           #
#                                                                             #
#   Contact: S. Janitza <janitza@ibe.med.uni-muenchen.de>                     #
#                                                                             #
#   File for reproducing Figure 7                                             #
#                                                                             #
###############################################################################

# NOTE: running this code requires installation of R packages snowfall, party, mvtnorm and ROCR

# please specify the path where the folder 'reproducible_files' is stored
path <- ""


setwd(paste(path, "reproducible_files/Real_Data_Applications/R_Objects/", sep = "")) # change working directory


# load all relevant R objects into the workspace

for(i in grep("pred_perf_", dir())) load(dir()[i])


setwd("../Figures/") # change working directory where figures shall be strored




# FIGURE 7
# --------

# execute the following commands to produce Figure 7 that is stored in the folder 'Figures'

graphics.off()
pdf(file = "Figure_7.pdf", width = 8.5, height = 4)

par(mfrow = c(1, 2), mar = c(7, 0, 0.5, 1), oma = c(0, 14, 0, 0.5))

boxplot(pred_perf_mammoexp["RPS_RF_ordinal",] / pred_perf_mammoexp["RPS_RF_classification",],
        pred_perf_SUPPORT["RPS_RF_ordinal",] / pred_perf_SUPPORT["RPS_RF_classification",], 
        pred_perf_NHANES["RPS_RF_ordinal",] / pred_perf_NHANES["RPS_RF_classification",], 
        pred_perf_wine["RPS_RF_ordinal",] / pred_perf_wine["RPS_RF_classification",],  
        pred_perf_vlbw["RPS_RF_ordinal",] / pred_perf_vlbw["RPS_RF_classification",], 
        horizontal = TRUE, yaxt = "n", main = "", ylim = c(0.92, 1.04), cex = 0.2)

abline(v = 1, lty = 2)
axis(side = 2, at = 5:1, las = 2, labels = c("Very Low Birth Weight (k = 9)", "Wine Quality (k = 6)", "NHANES (k = 5)", 
                                             "SUPPORT Study (k = 5)", "Mammography Experience (k = 3)"))

abline(v = 1, lty = 2)
arrows(1.005, -0.8, 1.04, -0.8, xpd = NA, length = 0.1)
arrows(0.995, -0.8, 0.96, -0.8, xpd = NA, length = 0.1)

mtext(side = 1, text = expression(paste("                       ", italic("RF ordinal"), "     ", italic("RF classifi-"))), line = 2.7, cex = 0.9)
mtext(side = 1, text = expression(paste("                               better      ", italic("cation"), " better")), line = 3.5, cex = 0.9)
mtext(side = 1, text = "RPS ratio", line = 5.5, cex = 1)

boxplot(pred_perf_mammoexp["ER_RF_ordinal",] / pred_perf_mammoexp["ER_RF_classification",],
        pred_perf_SUPPORT["ER_RF_ordinal",] / pred_perf_SUPPORT["ER_RF_classification",], 
        pred_perf_NHANES["ER_RF_ordinal",] / pred_perf_NHANES["ER_RF_classification",], 
        pred_perf_wine["ER_RF_ordinal",] / pred_perf_wine["ER_RF_classification",],  
        pred_perf_vlbw["ER_RF_ordinal",] / pred_perf_vlbw["ER_RF_classification",], 
        horizontal = TRUE, yaxt = "n", main = "", ylim = c(0.92, 1.04), cex = 0.2)

abline(v = 1, lty = 2)
arrows(1.005, -0.8, 1.04, -0.8, xpd = NA, length = 0.1)
arrows(0.995, -0.8, 0.96, -0.8, xpd = NA, length = 0.1)

mtext(side = 1, text = expression(paste("                       ", italic("RF ordinal"), "     ", italic("RF classifi-"))), line = 2.7, cex = 0.9)
mtext(side = 1, text = expression(paste("                               better      ", italic("cation"), " better")), line = 3.5, cex = 0.9)
mtext(side = 1, text = "Error rate ratio", line = 5.5, cex = 1)

graphics.off()


