###############################################################################
#                                                                             #
#   Reproducible files to 'Random Forests for Ordinal Response Data' (2014)   #
#   by Janitza, Tutz and Boulesteix                                           #
#                                                                             #
#   Contact: S. Janitza <janitza@ibe.med.uni-muenchen.de>                     #
#                                                                             #
#   File for reproducing Figure 8                                             #
#                                                                             #
###############################################################################

# NOTE: running this code requires installation of R packages snowfall, party, mvtnorm and ROCR

# please specify the path where the folder 'reproducible_files' is stored
path <- ""


setwd(paste(path, "reproducible_files/Real_Data_Applications/R_Objects/", sep = "")) # change working directory


# load all relevant R objects into the workspace

for(i in grep("VIM_perf_", dir())) load(dir()[i])


setwd("../Figures/") # change working directory where figures shall be strored




# FIGURE 8
# --------

# execute the following commands to produce Figure 8 that is stored in the folder 'Figures'

graphics.off()
pdf(file = "Figure_8.pdf", width = 4.2, height = 8)

par(mfrow = c(5, 2), mar = c(0, 0, 0, 0), oma = c(2, 8, 5, 0.5))


# for Very Low Birth Weight Data

boxplot(t(VIM_perf_vlbw[1:4,]), ylim = c(0.5, 1), xaxt = "n", col = c("gray95", "gray70", "gray55", "gray40"))

mtext(side = 3, text = expression(italic("RF ordinal")), line = 2, cex = 1.2)
mtext(side = 2, text = "Very Low Birth\n Weight (k = 9)", line = 4, cex = 1.2)
mtext(side = 2, text = "AUC", line = 2.5)

boxplot(t(VIM_perf_vlbw[5:8,]), ylim = c(0.5, 1), xaxt = "n", yaxt = "n", col = c("gray95", "gray70", "gray55", "gray40"))

mtext(side = 3, text = expression(italic("RF classification")), line = 2, cex = 1.2)


# for Wine Quality Data

boxplot(t(VIM_perf_wine[1:4,]), ylim = c(0.5, 1), xaxt = "n", col = c("gray95", "gray70", "gray55", "gray40"))

mtext(side = 2, text = "Wine Quality\n (k = 9)", line = 4, cex = 1.2)
mtext(side = 2, text = "AUC", line = 2.5)

boxplot(t(VIM_perf_wine[5:8,]), ylim = c(0.5, 1), xaxt = "n", yaxt = "n", col = c("gray95", "gray70", "gray55", "gray40"))


# for SUPPORT Study 

boxplot(t(VIM_perf_SUPPORT[1:4,]), ylim = c(0.5, 1), xaxt = "n", col = c("gray95", "gray70", "gray55", "gray40"))

mtext(side = 2, text = "SUPPORT Study\n (k = 5)", line = 4, cex = 1.2)
mtext(side = 2, text = "AUC", line = 2.5)

boxplot(t(VIM_perf_SUPPORT[5:8,]), ylim = c(0.5, 1), xaxt = "n", yaxt = "n", col = c("gray95", "gray70", "gray55", "gray40"))


# for NHANES Data

boxplot(t(VIM_perf_NHANES[1:4,]), ylim = c(0.5, 1), xaxt = "n", col = c("gray95", "gray70", "gray55", "gray40"))

mtext(side = 2, text = "NHANES\n (k = 5)", line = 4, cex = 1.2)
mtext(side = 2, text = "AUC", line = 2.5)

boxplot(t(VIM_perf_NHANES[5:8,]), ylim = c(0.5, 1), xaxt = "n", yaxt = "n", col = c("gray95", "gray70", "gray55", "gray40"))


# for Mammography Experience Data

boxplot(t(VIM_perf_mammoexp[1:4,]), ylim = c(0.5, 1), xaxt = "n", col = c("gray95", "gray70", "gray55", "gray40"))

mtext(side = 2, text = "Mammography Ex-\n perience (k = 3)", line = 4, cex = 1.2)
mtext(side = 2, text = "AUC", line = 2.5)

boxplot(t(VIM_perf_mammoexp[5:8,]), ylim = c(0.5, 1), xaxt = "n", yaxt = "n", col = c("gray95", "gray70", "gray55", "gray40"))

legend("bottomright", fill = c("gray95", "gray70", "gray55", "gray40"), legend = c("ER", "RPS", "MSE", "MAE"))


graphics.off()
