###############################################################################
#                                                                             #
#   Reproducible files to 'Random Forests for Ordinal Response Data' (2014)   #
#   by Janitza, Tutz and Boulesteix                                           #
#                                                                             #
#   Contact: S. Janitza <janitza@ibe.med.uni-muenchen.de>                     #
#                                                                             #
#   File for producing relevant R objects for Mammography Experience Data     #
#                                                                             #
###############################################################################

# NOTE: running this code requires installation of R packages snowfall, party, ROCR and TH.data

# please specify the path where the folder 'reproducible_files' is stored
path <- ""

# obtain Mammography Experience Data
library(TH.data)
data(mammoexp)

setwd(paste(path, "reproducible_files/Real_Data_Applications/R_Objects/", sep = "")) # change working directory

require(snowfall)

sfInit(parallel = TRUE, cpus = 100, type = "MPI") # if you won't do parallel computing set parallel = FALSE

sfLibrary(party)
sfLibrary(ROCR)

# source the code for our novel variable importance measures
sfSource("../../novel_VIMs.R")

# source the functions implementing the simulation studies
sfSource("../R_Code/functions.R") 

# specify response as nominal variable
mammoexp$ME <- factor(mammoexp$ME, ordered = FALSE)

sfExport("mammoexp")


# ---------------------------------------------
# Prediction Performance
# ---------------------------------------------

pred_perf_mammoexp <- sfSapply(1:500, function(z) prediction_performance(seed = z, data = mammoexp, yname = "ME"))
save(pred_perf_mammoexp, file = "pred_perf_mammoexp.Rda")


# ---------------------------------------------
# Variable importance
# ---------------------------------------------

VIM_perf_mammoexp <- sfSapply(1:500, function(z) variable_importance(seed = z, data = mammoexp, yname = "ME"))
save(VIM_perf_mammoexp, file = "VIM_perf_mammoexp.Rda")


sfStop()
