###############################################################################
#                                                                             #
#   Reproducible files to 'Random Forests for Ordinal Response Data' (2014)   #
#   by Janitza, Tutz and Boulesteix                                           #
#                                                                             #
#   Contact: S. Janitza <janitza@ibe.med.uni-muenchen.de>                     #
#                                                                             #
#   File for producing relevant R objects for Mammography Experience Data     #
#                                                                             #
###############################################################################

# NOTE: running this code requires installation of R packages snowfall, party, and ROCR. The NHANES data must be obtained by the reader
#       from the official website and must be loaded into the current working directory before running the codes

# please obtain the data and load it here into the working space:
load("")

#-------------------------------------------------------------------------------------------------------------------------

# Our considered NHANES dataset contains the following variables:
#
# > names(nhanes)
# [1] "sex"               "race"              "country_of_birth"  "education"         "marital_status"    "waistcircum"      
# [7] "Cholesterol"       "WBCcount"          "HealthStatus"      "AcuteIllness"      "depression"        "ToothCond"        
# [13] "sleepTrouble"      "wakeUp"            "cig"               "diabetes"          "asthma"            "heartFailure"     
# [19] "stroke"            "chronicBronchitis" "alcohol"           "heavyDrinker"      "medicalPlaceToGo"  "BPsys"            
# [25] "BPdias"            "age"               "BMI" 

# see Table A1 in Janitza, Binder and Boulesteix (2014) 'Pitfalls of Hypothesis Tests and Model Selection on Bootstrap Samples'
# (Technical Report 163, University of Munich) for a description on these variables. Note: we did not include variables CRP and income

#-------------------------------------------------------------------------------------------------------------------------


# please specify the path where the folder 'reproducible_files' is stored
path <- ""


setwd(paste(path, "reproducible_files/Real_Data_Applications/R_Objects/", sep = "")) # change working directory

require(snowfall)

sfInit(parallel = TRUE, cpus = 20, type = "MPI") # if you won't do parallel computing set parallel = FALSE

sfLibrary(party)
sfLibrary(ROCR)

# source the code for our novel variable importance measures
sfSource("../../novel_VIMs.R")

# source the functions implementing the simulation studies
sfSource("../R_Code/functions.R") 


# specify response as nominal variable
nhanes$HealthStatus <- factor(nhanes$HealthStatus, ordered = FALSE)

sfExport("nhanes")


# ---------------------------------------------
# Prediction Performance
# ---------------------------------------------

pred_perf_NHANES <- sfSapply(1:500, function(z) prediction_performance(seed = z, data = nhanes, yname = "HealthStatus"))
save(pred_perf_NHANES, file = "pred_perf_NHANES.Rda")


# ---------------------------------------------
# Variable importance
# ---------------------------------------------

VIM_perf_NHANES <- sfSapply(1:500, function(z) variable_importance(seed = z, data = nhanes, yname = "HealthStatus"))
save(VIM_perf_NHANES, file = "VIM_perf_NHANES.Rda")


sfStop()

