###############################################################################
#                                                                             #
#   Reproducible files to 'Random Forests for Ordinal Response Data' (2014)   #
#   by Janitza, Tutz and Boulesteix                                           #
#                                                                             #
#   Contact: S. Janitza <janitza@ibe.med.uni-muenchen.de>                     #
#                                                                             #
#   File for producing relevant R objects for the SUPPORT Study               #
#                                                                             #
###############################################################################

# NOTE: running this code requires installation of R packages snowfall, party and ROCR

# please obtain the data from the website and load it here into the working space:
load("support.sav")

# please specify the path where the folder 'reproducible_files' is stored
path <- ""


setwd(paste(path, "reproducible_files/Real_Data_Applications/R_Objects/", sep = "")) # change working directory

require(snowfall)

sfInit(parallel = TRUE, cpus = 50, type = "MPI") # if you won't do parallel computing set parallel = FALSE

sfLibrary(party)
sfLibrary(ROCR)

# source the code for our novel variable importance measures
sfSource("../../novel_VIMs.R")

# source the functions implementing the simulation studies
sfSource("../R_Code/functions.R") 



# use only the following variables
support <- support[, names(support) %in% c("sfdm2", "age", "sex", "dzgroup", "dzclass", "num.co", "race", "charges", "scoma",
                                        "avtisst", "meanbp", "wblc", "hrt", "resp", "temp", "crea", "sod")]

# exclude variables with more than 10% missing values
support <- support[, c(names(apply(support[, names(support) != "sfdm2"], 2, function(z) sum(is.na(z)) <= floor(0.1 * (nrow(support)-1)))), "sfdm2")]


# complete case analyses
support <- support[complete.cases(support),]


# specify response as nominal variable
support$sfdm2 <- factor(support$sfdm2, ordered = FALSE)

sfExport("support")


# ---------------------------------------------
# Prediction Performance
# ---------------------------------------------

pred_perf_SUPPORT <- sfSapply(1:500, function(z) prediction_performance(seed = z, data = support, yname = "sfdm2"))
save(pred_perf_SUPPORT, file = "pred_perf_SUPPORT.Rda")


# ---------------------------------------------
# Variable importance
# ---------------------------------------------

VIM_perf_SUPPORT <- sfSapply(1:500, function(z) variable_importance(seed = z, data = support, yname = "sfdm2"))
save(VIM_perf_SUPPORT, file = "VIM_perf_SUPPORT.Rda")


sfStop()
