###############################################################################
#                                                                             #
#   Reproducible files to 'Random Forests for Ordinal Response Data' (2014)   #
#   by Janitza, Tutz and Boulesteix                                           #
#                                                                             #
#   Contact: S. Janitza <janitza@ibe.med.uni-muenchen.de>                     #
#                                                                             #
#   File for producing relevant R objects for the Very Low Birth Weight Data  #
#                                                                             #
###############################################################################

# NOTE: running this code requires installation of R packages snowfall, party and ROCR 

# please obtain the data from the website and load it here into the working space:
load("vlbw.sav")


# please specify the path where the folder 'reproducible_files' is stored
path <- ""


setwd(paste(path, "reproducible_files/Real_Data_Applications/R_Objects/", sep = "")) # change working directory

require(snowfall)

sfInit(parallel = TRUE, cpus = 100, type = "MPI") # if you won't do parallel computing set parallel = FALSE

sfLibrary(party)
sfLibrary(ROCR)

# source the code for our novel variable importance measures
sfSource("../../novel_VIMs.R")

# source the functions implementing the simulation studies
sfSource("../R_Code/functions.R") 


# include only prenatal variables
vlbw <- vlbw[,names(vlbw) %in% c("apg1", "twn", "inout", "sex", "race", "delivery", "meth", "lol", "magsulf", "bwt", "toc")]

# convert variables to the correct data format
vlbw$twn     <- as.factor(vlbw$twn)
vlbw$magsulf <- as.factor(vlbw$magsulf)
vlbw$meth    <- as.factor(vlbw$meth)
vlbw$toc     <- as.factor(vlbw$toc)

# exclude observations with missing information
vlbw <- vlbw[complete.cases(vlbw),]

# exclude observations with too sparse levels
vlbw <- vlbw[vlbw$apg1 != 0,]                 # only 2 observations with apgar = 0
vlbw <- vlbw[vlbw$race != "oriental",]        # only 1 observation with race = oriental
vlbw <- vlbw[vlbw$race != "native American",] # only 4 observations with race = native American
vlbw$race <- factor(vlbw$race)


# specify response as nominal variable
vlbw$apg1 <- factor(vlbw$apg1, ordered = FALSE)

sfExport("vlbw")


# ---------------------------------------------
# Prediction Performance
# ---------------------------------------------

pred_perf_vlbw <- sfSapply(1:500, function(z) prediction_performance(seed = z, data = vlbw, yname = "apg1"))
save(pred_perf_vlbw, file = "pred_perf_vlbw.Rda")


# ---------------------------------------------
# Variable importance
# ---------------------------------------------

VIM_perf_vlbw <- sfSapply(1:500, function(z) variable_importance(seed = z, data = vlbw, yname = "apg1"))
save(VIM_perf_vlbw, file = "VIM_perf_vlbw.Rda")


sfStop()
