###############################################################################
#                                                                             #
#   Reproducible files to 'Random Forests for Ordinal Response Data' (2014)   #
#   by Janitza, Tutz and Boulesteix                                           #
#                                                                             #
#   Contact: S. Janitza <janitza@ibe.med.uni-muenchen.de>                     #
#                                                                             #
#   File for producing relevant R objects for Mammography Experience Data     #
#                                                                             #
###############################################################################

# NOTE: running this code requires installation of R packages snowfall, party and ROCR

# please obtain the data from the website and load it here into the working space:
wine <- read.csv("winequality-white.csv", header = TRUE, sep = ";")

# please specify the path where the folder 'reproducible_files' is stored
path <- ""


setwd(paste(path, "reproducible_files/Real_Data_Applications/R_Objects/", sep = "")) # change working directory

require(snowfall)

sfInit(parallel = TRUE, cpus = 20, type = "MPI") # if you won't do parallel computing set parallel = FALSE

sfLibrary(party)
sfLibrary(ROCR)

# source the code for our novel variable importance measures
sfSource("../../novel_VIMs.R")

# source the functions implementing the simulation studies
sfSource("../R_Code/functions.R") 

# exclude 5 observations with quality = 9 (too less observations in that class)
wine <- wine[wine$quality < 9,]

# specify response as nominal variable
wine$quality <- factor(wine$quality, ordered = FALSE)

sfExport("wine")


# ---------------------------------------------
# Prediction Performance
# ---------------------------------------------

pred_perf_wine <- sfSapply(1:500, 
                           function(z){
                             tryCatch({ # if there are technical problems in fitting the random forest, return NA
                               prediction_performance(seed = z, data = wine, yname = "quality")
                             }, error = function(e){
                               return(c(RPS_RF_ordinal = NA, ER_RF_ordinal = NA, RPS_RF_classification = NA, ER_RF_classification = NA))
                               })
                             })
save(pred_perf_wine, file = "pred_perf_wine.Rda")


# ---------------------------------------------
# Variable importance
# ---------------------------------------------

VIM_perf_wine <- sfSapply(1:500, function(z) variable_importance(seed = z, data = wine, yname = "quality"))
save(VIM_perf_wine, file = "VIM_perf_wine.Rda")


sfStop()
