###############################################################################
#                                                                             #
#   Reproducible files to 'Random Forests for Ordinal Response Data' (2014)   #
#   by Janitza, Tutz and Boulesteix                                           #
#                                                                             #
#   Contact: S. Janitza <janitza@ibe.med.uni-muenchen.de>                     #
#                                                                             #
#   File for reproducing Figure 2                                             #
#                                                                             #
###############################################################################

# NOTE: running this code requires installation of R packages snowfall, party, mvtnorm and ROCR

# please specify the path where the folder 'reproducible_files' is stored
path <- ""


setwd(paste(path, "reproducible_files/Simulation_Studies/R_Objects/", sep = "")) # change working directory


# load all relevant R objects into the workspace

for(i in grep("sim_", dir())) load(dir()[i])


setwd("../Figures/") # change working directory where figures shall be strored



# FIGURE 2
# --------

# execute the following commands to produce Figure 2 that is stored in the folder 'Figures'

graphics.off()
pdf(file = "Figure_2.pdf", width = 5, height = 6)

par(mfrow = c(3,2), mar = c(0, 0, 0, 0), oma = c(8, 7, 4, 0.8), cex.axis = 1.5)


# row with zeta = 0.6

boxplot(sim_ncat3_n200_cor["RPS_RF_ordinal",]/sim_ncat3_n200_cor["RPS_RF_classification",],
        sim_ncat6_n200_cor["RPS_RF_ordinal",]/sim_ncat6_n200_cor["RPS_RF_classification",],
        sim_ncat9_n200_cor["RPS_RF_ordinal",]/sim_ncat9_n200_cor["RPS_RF_classification",],
        horizontal = TRUE, xaxt = "n", yaxt = "n", ylim = c(0.92, 1.04))

abline(v = 1, lty = 2)
axis(2, at = 1:3, labels = c("k = 3", "k = 6", "k = 9"), las = 2)
mtext(side = 2, text = expression(zeta ~ " = 0.6"), line = 5, cex = 1.1)
mtext(side = 3, text = "With correlations", line = 1, cex = 1.1)


boxplot(sim_ncat3_n200_nocor["RPS_RF_ordinal",]/sim_ncat3_n200_nocor["RPS_RF_classification",],
        sim_ncat6_n200_nocor["RPS_RF_ordinal",]/sim_ncat6_n200_nocor["RPS_RF_classification",],
        sim_ncat9_n200_nocor["RPS_RF_ordinal",]/sim_ncat9_n200_nocor["RPS_RF_classification",],
        horizontal = TRUE, xaxt = "n", yaxt = "n", ylim = c(0.92, 1.04))

abline(v = 1, lty = 2)
mtext(side = 3, text = "Without correlations", line = 1, cex = 1.1)


# row with zeta = 1

boxplot(sim_ncat3_n200_cor_mix1["RPS_RF_ordinal",]/sim_ncat3_n200_cor_mix1["RPS_RF_classification",],
        sim_ncat6_n200_cor_mix1["RPS_RF_ordinal",]/sim_ncat6_n200_cor_mix1["RPS_RF_classification",],
        sim_ncat9_n200_cor_mix1["RPS_RF_ordinal",]/sim_ncat9_n200_cor_mix1["RPS_RF_classification",],
        horizontal = TRUE, xaxt = "n", yaxt = "n", ylim = c(0.92, 1.04))

abline(v = 1, lty = 2)
axis(2, at = 1:3, labels = c("k = 3", "k = 6", "k = 9"), las = 2)
mtext(side = 2, text = expression(zeta ~ " = 1"), line = 5, cex = 1.1)


boxplot(sim_ncat3_n200_nocor_mix1["RPS_RF_ordinal",]/sim_ncat3_n200_nocor_mix1["RPS_RF_classification",],
        sim_ncat6_n200_nocor_mix1["RPS_RF_ordinal",]/sim_ncat6_n200_nocor_mix1["RPS_RF_classification",],
        sim_ncat9_n200_nocor_mix1["RPS_RF_ordinal",]/sim_ncat9_n200_nocor_mix1["RPS_RF_classification",],
        horizontal = TRUE, xaxt = "n", yaxt = "n", ylim = c(0.92, 1.04))

abline(v = 1, lty = 2)


# row with zeta = 0

boxplot(sim_ncat3_n200_cor_mix2["RPS_RF_ordinal",]/sim_ncat3_n200_cor_mix2["RPS_RF_classification",],
        sim_ncat6_n200_cor_mix2["RPS_RF_ordinal",]/sim_ncat6_n200_cor_mix2["RPS_RF_classification",],
        sim_ncat9_n200_cor_mix2["RPS_RF_ordinal",]/sim_ncat9_n200_cor_mix2["RPS_RF_classification",],
        horizontal = TRUE, xaxt = "n", yaxt = "n", ylim = c(0.92, 1.04))

abline(v = 1, lty = 2)
axis(2, at = 1:3, labels = c("k = 3", "k = 6", "k = 9"), las = 2)
axis(1, at = c(0.92, 0.94, 0.96, 0.98, 1, 1.02, 1.04), labels = c("0.92", "", "0.96", "", "1.00", "", ""))
mtext(side = 2, text = expression(zeta ~ " = 0"), line = 5, cex = 1.1)

arrows(1.005, -0.4, 1.04, -0.4, xpd = NA, length = 0.1)
arrows(0.995, -0.4, 0.96, -0.4, xpd = NA, length = 0.1)

mtext(side = 1, text = expression(paste("                       ", italic("RF ordinal"), "     ", italic("RF classifi-"))), line = 3.5, cex = 0.7)
mtext(side = 1, text = expression(paste("                               better      ", italic("cation"), " better")), line = 4.5, cex = 0.7)
mtext(side = 1, text = "RPS ratio", line = 6.5, cex = 1)

boxplot(sim_ncat3_n200_nocor_mix2["RPS_RF_ordinal",]/sim_ncat3_n200_nocor_mix2["RPS_RF_classification",],
        sim_ncat6_n200_nocor_mix2["RPS_RF_ordinal",]/sim_ncat6_n200_nocor_mix2["RPS_RF_classification",],
        sim_ncat9_n200_nocor_mix2["RPS_RF_ordinal",]/sim_ncat9_n200_nocor_mix2["RPS_RF_classification",],
        horizontal = TRUE, xaxt = "n", xlab = "RPS Ratio", yaxt = "n", ylim = c(0.92, 1.04))

abline(v = 1, lty = 2)
axis(1, at = c(0.92, 0.94, 0.96, 0.98, 1, 1.02, 1.04), labels = c("  0.92", "", "0.96", "", "1.00", "", "1.04"))

arrows(1.005, -0.4, 1.04, -0.4, xpd = NA, length = 0.1)
arrows(0.995, -0.4, 0.96, -0.4, xpd = NA, length = 0.1)

mtext(side = 1, text = expression(paste("                       ", italic("RF ordinal"), "     ", italic("RF classifi-"))), line = 3.5, cex = 0.7)
mtext(side = 1, text = expression(paste("                               better      ", italic("cation"), " better")), line = 4.5, cex = 0.7)
mtext(side = 1, text = "RPS ratio", line = 6.5, cex = 1)

graphics.off()


