###############################################################################
#                                                                             #
#   Reproducible files to 'Random Forests for Ordinal Response Data' (2014)   #
#   by Janitza, Tutz and Boulesteix                                           #
#                                                                             #
#   Contact: S. Janitza <janitza@ibe.med.uni-muenchen.de>                     #
#                                                                             #
#   File for reproducing Figure 6                                             #
#                                                                             #
###############################################################################

# NOTE: running this code requires installation of R packages snowfall, party, mvtnorm and ROCR

# please specify the path where the folder 'reproducible_files' is stored
path <- ""


setwd(paste(path, "reproducible_files/Simulation_Studies/R_Objects/", sep = "")) # change working directory


# load all relevant R objects into the workspace

for(i in grep("split_", dir())) load(dir()[i])


setwd("../Figures/") # change working directory where figures shall be strored




# FIGURE 6
# --------

# execute the following commands to produce Figure 6 that is stored in the folder 'Figures'

graphics.off()
pdf(file = "Figure_6.pdf", width = 5, height = 6)

par(mfrow = c(3,2), mar = c(0, 0, 0, 0), oma = c(12, 7, 5, 0.5), cex.axis = 1.2)

boxplot(cbind(t(split_ncat9_n200_cor), NA, t(split_ncat6_n200_cor), NA, t(split_ncat3_n200_cor)), ylim = c(0.3, 0.85), xaxt = "n")
mtext(side = 2, text = expression(zeta ~ " = 0.6"), line = 5, cex = 1.1)
mtext(side = 2, text = "Tree fraction", line = 2.5)
axis(3, at = c(1.5, 4.5, 7.5), c("k = 9", "k = 6", "k = 3"), outer = TRUE, lwd.ticks = 0)
boxplot(cbind(t(split_ncat9_n200_nocor), NA, t(split_ncat6_n200_nocor), NA, t(split_ncat3_n200_nocor)), ylim = c(0.3, 0.85), yaxt = "n", xaxt = "n")

axis(3, at = c(1.5, 4.5, 7.5), c("k = 9", "k = 6", "k = 3"), outer = TRUE, lwd.ticks = 0)
mtext(side = 3, text = "      With correlations          Without correlations", cex = 1.1, line = 3, outer = TRUE)

boxplot(cbind(t(split_ncat9_n200_cor_mix1), NA, t(split_ncat6_n200_cor_mix1), NA, t(split_ncat3_n200_cor_mix1)), ylim = c(0.3, 0.85), xaxt = "n", ylab = "Tree fraction")
mtext(side = 2, text = expression(zeta ~ " = 1"), line = 5, cex = 1.1)
mtext(side = 2, text = "Tree fraction", line = 2.5)
boxplot(cbind(t(split_ncat9_n200_nocor_mix1), NA, t(split_ncat6_n200_nocor_mix1), NA, t(split_ncat3_n200_nocor_mix1)), ylim = c(0.3, 0.85), yaxt = "n", xaxt = "n")


boxplot(cbind(t(split_ncat9_n200_cor_mix2), NA, t(split_ncat6_n200_cor_mix2), NA, t(split_ncat3_n200_cor_mix2)), ylim = c(0.3, 0.85), xaxt = "n", ylab = "Tree fraction")
#axis(1, at = c(1.5, 4.5, 7.5), c("k = 9", "k = 6", "k = 3"), outer = TRUE)
mtext(side = 2, text = expression(zeta ~ " = 0"), line = 5, cex = 1.1)
mtext(side = 2, text = "Tree fraction", line = 2.5)
axis(1, at = c(1, 2, 4, 5, 7, 8), labels = rep(c(expression(italic("RF ordinal")), expression(italic("RF classification"))), length = 6), outer = TRUE, las = 2)

boxplot(cbind(t(split_ncat9_n200_nocor_mix2), NA, t(split_ncat6_n200_nocor_mix2), NA, t(split_ncat3_n200_nocor_mix2)), ylim = c(0.3, 0.85), yaxt = "n", xaxt = "n")

axis(1, at = c(1, 2, 4, 5, 7, 8), labels = rep(c(expression(italic("RF ordinal")), expression(italic("RF classification"))), length = 6), outer = TRUE, las = 2)

graphics.off()
