###############################################################################
#                                                                             #
#   Reproducible files to 'Random Forests for Ordinal Response Data' (2014)   #
#   by Janitza, Tutz and Boulesteix                                           #
#                                                                             #
#   Contact: S. Janitza <janitza@ibe.med.uni-muenchen.de>                     #
#                                                                             #
#   File for reproducing Figures 3-5                                          #
#                                                                             #
###############################################################################

# NOTE: running this code requires installation of R packages snowfall, party, mvtnorm and ROCR

# please specify the path where the folder 'reproducible_files' is stored
path <- ""


setwd(paste(path, "reproducible_files/Simulation_Studies/R_Objects/", sep = "")) # change working directory


# load all relevant R objects into the workspace

for(i in grep("sim_", dir())) load(dir()[i])


setwd("../Figures/") # change working directory where figures shall be strored




# FIGURE 3
# --------

# execute the following commands to produce Figure 3 that is stored in the folder 'Figures'

graphics.off()
pdf(file = "Figure_3.pdf", width = 6, height = 5)

par(mfrow = c(3, 4), mar = c(0, 0, 0, 0), oma = c(0.5, 9, 5, 0.5))

# row with zeta = 0.6

boxplot(sim_ncat9_n200_cor["AUC_ERVIM_RF_ordinal",],
        sim_ncat9_n200_cor["AUC_RPSVIM_RF_ordinal",],
        sim_ncat9_n200_cor["AUC_MSEVIM_RF_ordinal",], 
        sim_ncat9_n200_cor["AUC_MAEVIM_RF_ordinal",],
        ylim = c(0.5, 1), xaxt = "n", col = c("gray95", "gray70", "gray55", "gray40"))


mtext(side = 2, text = expression(zeta ~ " = 0.6"), line = 5, cex = 1.5)
mtext(side = 2, text = "AUC", line = 2.5)
mtext(side = 3, text = "    With correlations                 Without correlations", cex = 1.1, line = 3, outer = TRUE)
mtext(side = 3, text = expression(italic("RF ordinal")), cex = 1, line = 1)


boxplot(sim_ncat9_n200_cor["AUC_ERVIM_RF_classification",],
        sim_ncat9_n200_cor["AUC_RPSVIM_RF_classification",],
        sim_ncat9_n200_cor["AUC_MSEVIM_RF_classification",], 
        sim_ncat9_n200_cor["AUC_MAEVIM_RF_classification",],
        ylim = c(0.5, 1), xaxt = "n", yaxt = "n", col = c("gray95", "gray70", "gray55", "gray40"))

mtext(side = 3, text = expression(italic("RF classification")), cex = 1, line = 1)

boxplot(sim_ncat9_n200_nocor["AUC_ERVIM_RF_ordinal",],
        sim_ncat9_n200_nocor["AUC_RPSVIM_RF_ordinal",],
        sim_ncat9_n200_nocor["AUC_MSEVIM_RF_ordinal",], 
        sim_ncat9_n200_nocor["AUC_MAEVIM_RF_ordinal",],
        ylim = c(0.5, 1), xaxt = "n", yaxt = "n", col = c("gray95", "gray70", "gray55", "gray40"))

mtext(side = 3, text = expression(italic("RF ordinal")), cex = 1, line = 1)

boxplot(sim_ncat9_n200_nocor["AUC_ERVIM_RF_classification",],
        sim_ncat9_n200_nocor["AUC_RPSVIM_RF_classification",],
        sim_ncat9_n200_nocor["AUC_MSEVIM_RF_classification",], 
        sim_ncat9_n200_nocor["AUC_MAEVIM_RF_classification",],
        ylim = c(0.5, 1), yaxt = "n", xaxt = "n", col = c("gray95", "gray70", "gray55", "gray40"))

mtext(side = 3, text = expression(italic("RF classification")), cex = 1, line = 1)


# row with zeta = 1

boxplot(sim_ncat9_n200_cor_mix1["AUC_ERVIM_RF_ordinal",],
        sim_ncat9_n200_cor_mix1["AUC_RPSVIM_RF_ordinal",],
        sim_ncat9_n200_cor_mix1["AUC_MSEVIM_RF_ordinal",], 
        sim_ncat9_n200_cor_mix1["AUC_MAEVIM_RF_ordinal",],
        ylim = c(0.5, 1), xaxt = "n", col = c("gray95", "gray70", "gray55", "gray40"))

mtext(side = 2, text = expression(zeta ~ " = 1"), line = 5, cex = 1.5)
mtext(side = 2, text = "AUC", line = 2.5)

boxplot(sim_ncat9_n200_cor_mix1["AUC_ERVIM_RF_classification",],
        sim_ncat9_n200_cor_mix1["AUC_RPSVIM_RF_classification",],
        sim_ncat9_n200_cor_mix1["AUC_MSEVIM_RF_classification",], 
        sim_ncat9_n200_cor_mix1["AUC_MAEVIM_RF_classification",],
        ylim = c(0.5, 1), xaxt = "n", yaxt = "n", col = c("gray95", "gray70", "gray55", "gray40"))

boxplot(sim_ncat9_n200_nocor_mix1["AUC_ERVIM_RF_ordinal",],
        sim_ncat9_n200_nocor_mix1["AUC_RPSVIM_RF_ordinal",],
        sim_ncat9_n200_nocor_mix1["AUC_MSEVIM_RF_ordinal",], 
        sim_ncat9_n200_nocor_mix1["AUC_MAEVIM_RF_ordinal",],
        ylim = c(0.5, 1), xaxt = "n", yaxt = "n", col = c("gray95", "gray70", "gray55", "gray40"))

boxplot(sim_ncat9_n200_nocor_mix1["AUC_ERVIM_RF_classification",],
        sim_ncat9_n200_nocor_mix1["AUC_RPSVIM_RF_classification",],
        sim_ncat9_n200_nocor_mix1["AUC_MSEVIM_RF_classification",], 
        sim_ncat9_n200_nocor_mix1["AUC_MAEVIM_RF_classification",],
        ylim = c(0.5, 1), yaxt = "n", xaxt = "n", col = c("gray95", "gray70", "gray55", "gray40"))


# row with zeta = 0

boxplot(sim_ncat9_n200_cor_mix2["AUC_ERVIM_RF_ordinal",],
        sim_ncat9_n200_cor_mix2["AUC_RPSVIM_RF_ordinal",],
        sim_ncat9_n200_cor_mix2["AUC_MSEVIM_RF_ordinal",], 
        sim_ncat9_n200_cor_mix2["AUC_MAEVIM_RF_ordinal",],
        ylim = c(0.5, 1), xaxt = "n", col = c("gray95", "gray70", "gray55", "gray40"))

mtext(side = 2, text = expression(zeta ~ " = 0"), line = 5, cex = 1.5)
mtext(side = 2, text = "AUC", line = 2.5)

boxplot(sim_ncat9_n200_cor_mix2["AUC_ERVIM_RF_classification",],
        sim_ncat9_n200_cor_mix2["AUC_RPSVIM_RF_classification",],
        sim_ncat9_n200_cor_mix2["AUC_MSEVIM_RF_classification",], 
        sim_ncat9_n200_cor_mix2["AUC_MAEVIM_RF_classification",],
        ylim = c(0.5, 1), xaxt = "n", yaxt = "n", col = c("gray95", "gray70", "gray55", "gray40"))

boxplot(sim_ncat9_n200_nocor_mix2["AUC_ERVIM_RF_ordinal",],
        sim_ncat9_n200_nocor_mix2["AUC_RPSVIM_RF_ordinal",],
        sim_ncat9_n200_nocor_mix2["AUC_MSEVIM_RF_ordinal",], 
        sim_ncat9_n200_nocor_mix2["AUC_MAEVIM_RF_ordinal",],
        ylim = c(0.5, 1), xaxt = "n", yaxt = "n", col = c("gray95", "gray70", "gray55", "gray40"))

boxplot(sim_ncat9_n200_nocor_mix2["AUC_ERVIM_RF_classification",],
        sim_ncat9_n200_nocor_mix2["AUC_RPSVIM_RF_classification",],
        sim_ncat9_n200_nocor_mix2["AUC_MSEVIM_RF_classification",], 
        sim_ncat9_n200_nocor_mix2["AUC_MAEVIM_RF_classification",],
        ylim = c(0.5, 1), yaxt = "n", xaxt = "n", col = c("gray95", "gray70", "gray55", "gray40"))


legend("bottomright", fill = c("gray95", "gray70", "gray55", "gray40"), legend = c("ER", "RPS", "MSE", "MAE"))

graphics.off()




# FIGURE 4
# --------

# execute the following commands to produce Figure 4 that is stored in the folder 'Figures'

graphics.off()
pdf(file = "Figure_4.pdf", width = 6, height = 5)

par(mfrow = c(3, 4), mar = c(0, 0, 0, 0), oma = c(0.5, 9, 5, 0.5))

# row with zeta = 0.6

boxplot(sim_ncat6_n200_cor["AUC_ERVIM_RF_ordinal",],
        sim_ncat6_n200_cor["AUC_RPSVIM_RF_ordinal",],
        sim_ncat6_n200_cor["AUC_MSEVIM_RF_ordinal",], 
        sim_ncat6_n200_cor["AUC_MAEVIM_RF_ordinal",],
        ylim = c(0.5, 1), xaxt = "n", col = c("gray95", "gray70", "gray55", "gray40"))


mtext(side = 2, text = expression(zeta ~ " = 0.6"), line = 5, cex = 1.5)
mtext(side = 2, text = "AUC", line = 2.5)
mtext(side = 3, text = "    With correlations                 Without correlations", cex = 1.1, line = 3, outer = TRUE)
mtext(side = 3, text = expression(italic("RF ordinal")), cex = 1, line = 1)


boxplot(sim_ncat6_n200_cor["AUC_ERVIM_RF_classification",],
        sim_ncat6_n200_cor["AUC_RPSVIM_RF_classification",],
        sim_ncat6_n200_cor["AUC_MSEVIM_RF_classification",], 
        sim_ncat6_n200_cor["AUC_MAEVIM_RF_classification",],
        ylim = c(0.5, 1), xaxt = "n", yaxt = "n", col = c("gray95", "gray70", "gray55", "gray40"))

mtext(side = 3, text = expression(italic("RF classification")), cex = 1, line = 1)

boxplot(sim_ncat6_n200_nocor["AUC_ERVIM_RF_ordinal",],
        sim_ncat6_n200_nocor["AUC_RPSVIM_RF_ordinal",],
        sim_ncat6_n200_nocor["AUC_MSEVIM_RF_ordinal",], 
        sim_ncat6_n200_nocor["AUC_MAEVIM_RF_ordinal",],
        ylim = c(0.5, 1), xaxt = "n", yaxt = "n", col = c("gray95", "gray70", "gray55", "gray40"))

mtext(side = 3, text = expression(italic("RF ordinal")), cex = 1, line = 1)

boxplot(sim_ncat6_n200_nocor["AUC_ERVIM_RF_classification",],
        sim_ncat6_n200_nocor["AUC_RPSVIM_RF_classification",],
        sim_ncat6_n200_nocor["AUC_MSEVIM_RF_classification",], 
        sim_ncat6_n200_nocor["AUC_MAEVIM_RF_classification",],
        ylim = c(0.5, 1), yaxt = "n", xaxt = "n", col = c("gray95", "gray70", "gray55", "gray40"))

mtext(side = 3, text = expression(italic("RF classification")), cex = 1, line = 1)


# row with zeta = 1

boxplot(sim_ncat6_n200_cor_mix1["AUC_ERVIM_RF_ordinal",],
        sim_ncat6_n200_cor_mix1["AUC_RPSVIM_RF_ordinal",],
        sim_ncat6_n200_cor_mix1["AUC_MSEVIM_RF_ordinal",], 
        sim_ncat6_n200_cor_mix1["AUC_MAEVIM_RF_ordinal",],
        ylim = c(0.5, 1), xaxt = "n", col = c("gray95", "gray70", "gray55", "gray40"))

mtext(side = 2, text = expression(zeta ~ " = 1"), line = 5, cex = 1.5)
mtext(side = 2, text = "AUC", line = 2.5)

boxplot(sim_ncat6_n200_cor_mix1["AUC_ERVIM_RF_classification",],
        sim_ncat6_n200_cor_mix1["AUC_RPSVIM_RF_classification",],
        sim_ncat6_n200_cor_mix1["AUC_MSEVIM_RF_classification",], 
        sim_ncat6_n200_cor_mix1["AUC_MAEVIM_RF_classification",],
        ylim = c(0.5, 1), xaxt = "n", yaxt = "n", col = c("gray95", "gray70", "gray55", "gray40"))

boxplot(sim_ncat6_n200_nocor_mix1["AUC_ERVIM_RF_ordinal",],
        sim_ncat6_n200_nocor_mix1["AUC_RPSVIM_RF_ordinal",],
        sim_ncat6_n200_nocor_mix1["AUC_MSEVIM_RF_ordinal",], 
        sim_ncat6_n200_nocor_mix1["AUC_MAEVIM_RF_ordinal",],
        ylim = c(0.5, 1), xaxt = "n", yaxt = "n", col = c("gray95", "gray70", "gray55", "gray40"))

boxplot(sim_ncat6_n200_nocor_mix1["AUC_ERVIM_RF_classification",],
        sim_ncat6_n200_nocor_mix1["AUC_RPSVIM_RF_classification",],
        sim_ncat6_n200_nocor_mix1["AUC_MSEVIM_RF_classification",], 
        sim_ncat6_n200_nocor_mix1["AUC_MAEVIM_RF_classification",],
        ylim = c(0.5, 1), yaxt = "n", xaxt = "n", col = c("gray95", "gray70", "gray55", "gray40"))


# row with zeta = 0

boxplot(sim_ncat6_n200_cor_mix2["AUC_ERVIM_RF_ordinal",],
        sim_ncat6_n200_cor_mix2["AUC_RPSVIM_RF_ordinal",],
        sim_ncat6_n200_cor_mix2["AUC_MSEVIM_RF_ordinal",], 
        sim_ncat6_n200_cor_mix2["AUC_MAEVIM_RF_ordinal",],
        ylim = c(0.5, 1), xaxt = "n", col = c("gray95", "gray70", "gray55", "gray40"))

mtext(side = 2, text = expression(zeta ~ " = 0"), line = 5, cex = 1.5)
mtext(side = 2, text = "AUC", line = 2.5)

boxplot(sim_ncat6_n200_cor_mix2["AUC_ERVIM_RF_classification",],
        sim_ncat6_n200_cor_mix2["AUC_RPSVIM_RF_classification",],
        sim_ncat6_n200_cor_mix2["AUC_MSEVIM_RF_classification",], 
        sim_ncat6_n200_cor_mix2["AUC_MAEVIM_RF_classification",],
        ylim = c(0.5, 1), xaxt = "n", yaxt = "n", col = c("gray95", "gray70", "gray55", "gray40"))

boxplot(sim_ncat6_n200_nocor_mix2["AUC_ERVIM_RF_ordinal",],
        sim_ncat6_n200_nocor_mix2["AUC_RPSVIM_RF_ordinal",],
        sim_ncat6_n200_nocor_mix2["AUC_MSEVIM_RF_ordinal",], 
        sim_ncat6_n200_nocor_mix2["AUC_MAEVIM_RF_ordinal",],
        ylim = c(0.5, 1), xaxt = "n", yaxt = "n", col = c("gray95", "gray70", "gray55", "gray40"))

boxplot(sim_ncat6_n200_nocor_mix2["AUC_ERVIM_RF_classification",],
        sim_ncat6_n200_nocor_mix2["AUC_RPSVIM_RF_classification",],
        sim_ncat6_n200_nocor_mix2["AUC_MSEVIM_RF_classification",], 
        sim_ncat6_n200_nocor_mix2["AUC_MAEVIM_RF_classification",],
        ylim = c(0.5, 1), yaxt = "n", xaxt = "n", col = c("gray95", "gray70", "gray55", "gray40"))


legend("bottomright", fill = c("gray95", "gray70", "gray55", "gray40"), legend = c("ER", "RPS", "MSE", "MAE"))

graphics.off()




# FIGURE 5
# --------

# execute the following commands to produce Figure 5 that is stored in the folder 'Figures'

graphics.off()
pdf(file = "Figure_5.pdf", width = 6, height = 5)

par(mfrow = c(3, 4), mar = c(0, 0, 0, 0), oma = c(0.5, 9, 5, 0.5))

# row with zeta = 0.6

boxplot(sim_ncat3_n200_cor["AUC_ERVIM_RF_ordinal",],
        sim_ncat3_n200_cor["AUC_RPSVIM_RF_ordinal",],
        sim_ncat3_n200_cor["AUC_MSEVIM_RF_ordinal",], 
        sim_ncat3_n200_cor["AUC_MAEVIM_RF_ordinal",],
        ylim = c(0.5, 1), xaxt = "n", col = c("gray95", "gray70", "gray55", "gray40"))


mtext(side = 2, text = expression(zeta ~ " = 0.6"), line = 5, cex = 1.5)
mtext(side = 2, text = "AUC", line = 2.5)
mtext(side = 3, text = "    With correlations                 Without correlations", cex = 1.1, line = 3, outer = TRUE)
mtext(side = 3, text = expression(italic("RF ordinal")), cex = 1, line = 1)


boxplot(sim_ncat3_n200_cor["AUC_ERVIM_RF_classification",],
        sim_ncat3_n200_cor["AUC_RPSVIM_RF_classification",],
        sim_ncat3_n200_cor["AUC_MSEVIM_RF_classification",], 
        sim_ncat3_n200_cor["AUC_MAEVIM_RF_classification",],
        ylim = c(0.5, 1), xaxt = "n", yaxt = "n", col = c("gray95", "gray70", "gray55", "gray40"))

mtext(side = 3, text = expression(italic("RF classification")), cex = 1, line = 1)

boxplot(sim_ncat3_n200_nocor["AUC_ERVIM_RF_ordinal",],
        sim_ncat3_n200_nocor["AUC_RPSVIM_RF_ordinal",],
        sim_ncat3_n200_nocor["AUC_MSEVIM_RF_ordinal",], 
        sim_ncat3_n200_nocor["AUC_MAEVIM_RF_ordinal",],
        ylim = c(0.5, 1), xaxt = "n", yaxt = "n", col = c("gray95", "gray70", "gray55", "gray40"))

mtext(side = 3, text = expression(italic("RF ordinal")), cex = 1, line = 1)

boxplot(sim_ncat3_n200_nocor["AUC_ERVIM_RF_classification",],
        sim_ncat3_n200_nocor["AUC_RPSVIM_RF_classification",],
        sim_ncat3_n200_nocor["AUC_MSEVIM_RF_classification",], 
        sim_ncat3_n200_nocor["AUC_MAEVIM_RF_classification",],
        ylim = c(0.5, 1), yaxt = "n", xaxt = "n", col = c("gray95", "gray70", "gray55", "gray40"))

mtext(side = 3, text = expression(italic("RF classification")), cex = 1, line = 1)


# row with zeta = 1

boxplot(sim_ncat3_n200_cor_mix1["AUC_ERVIM_RF_ordinal",],
        sim_ncat3_n200_cor_mix1["AUC_RPSVIM_RF_ordinal",],
        sim_ncat3_n200_cor_mix1["AUC_MSEVIM_RF_ordinal",], 
        sim_ncat3_n200_cor_mix1["AUC_MAEVIM_RF_ordinal",],
        ylim = c(0.5, 1), xaxt = "n", col = c("gray95", "gray70", "gray55", "gray40"))

mtext(side = 2, text = expression(zeta ~ " = 1"), line = 5, cex = 1.5)
mtext(side = 2, text = "AUC", line = 2.5)

boxplot(sim_ncat3_n200_cor_mix1["AUC_ERVIM_RF_classification",],
        sim_ncat3_n200_cor_mix1["AUC_RPSVIM_RF_classification",],
        sim_ncat3_n200_cor_mix1["AUC_MSEVIM_RF_classification",], 
        sim_ncat3_n200_cor_mix1["AUC_MAEVIM_RF_classification",],
        ylim = c(0.5, 1), xaxt = "n", yaxt = "n", col = c("gray95", "gray70", "gray55", "gray40"))

boxplot(sim_ncat3_n200_nocor_mix1["AUC_ERVIM_RF_ordinal",],
        sim_ncat3_n200_nocor_mix1["AUC_RPSVIM_RF_ordinal",],
        sim_ncat3_n200_nocor_mix1["AUC_MSEVIM_RF_ordinal",], 
        sim_ncat3_n200_nocor_mix1["AUC_MAEVIM_RF_ordinal",],
        ylim = c(0.5, 1), xaxt = "n", yaxt = "n", col = c("gray95", "gray70", "gray55", "gray40"))

boxplot(sim_ncat3_n200_nocor_mix1["AUC_ERVIM_RF_classification",],
        sim_ncat3_n200_nocor_mix1["AUC_RPSVIM_RF_classification",],
        sim_ncat3_n200_nocor_mix1["AUC_MSEVIM_RF_classification",], 
        sim_ncat3_n200_nocor_mix1["AUC_MAEVIM_RF_classification",],
        ylim = c(0.5, 1), yaxt = "n", xaxt = "n", col = c("gray95", "gray70", "gray55", "gray40"))


# row with zeta = 0

boxplot(sim_ncat3_n200_cor_mix2["AUC_ERVIM_RF_ordinal",],
        sim_ncat3_n200_cor_mix2["AUC_RPSVIM_RF_ordinal",],
        sim_ncat3_n200_cor_mix2["AUC_MSEVIM_RF_ordinal",], 
        sim_ncat3_n200_cor_mix2["AUC_MAEVIM_RF_ordinal",],
        ylim = c(0.5, 1), xaxt = "n", col = c("gray95", "gray70", "gray55", "gray40"))

mtext(side = 2, text = expression(zeta ~ " = 0"), line = 5, cex = 1.5)
mtext(side = 2, text = "AUC", line = 2.5)

boxplot(sim_ncat3_n200_cor_mix2["AUC_ERVIM_RF_classification",],
        sim_ncat3_n200_cor_mix2["AUC_RPSVIM_RF_classification",],
        sim_ncat3_n200_cor_mix2["AUC_MSEVIM_RF_classification",], 
        sim_ncat3_n200_cor_mix2["AUC_MAEVIM_RF_classification",],
        ylim = c(0.5, 1), xaxt = "n", yaxt = "n", col = c("gray95", "gray70", "gray55", "gray40"))

boxplot(sim_ncat3_n200_nocor_mix2["AUC_ERVIM_RF_ordinal",],
        sim_ncat3_n200_nocor_mix2["AUC_RPSVIM_RF_ordinal",],
        sim_ncat3_n200_nocor_mix2["AUC_MSEVIM_RF_ordinal",], 
        sim_ncat3_n200_nocor_mix2["AUC_MAEVIM_RF_ordinal",],
        ylim = c(0.5, 1), xaxt = "n", yaxt = "n", col = c("gray95", "gray70", "gray55", "gray40"))

boxplot(sim_ncat3_n200_nocor_mix2["AUC_ERVIM_RF_classification",],
        sim_ncat3_n200_nocor_mix2["AUC_RPSVIM_RF_classification",],
        sim_ncat3_n200_nocor_mix2["AUC_MSEVIM_RF_classification",], 
        sim_ncat3_n200_nocor_mix2["AUC_MAEVIM_RF_classification",],
        ylim = c(0.5, 1), yaxt = "n", xaxt = "n", col = c("gray95", "gray70", "gray55", "gray40"))


legend("bottomright", fill = c("gray95", "gray70", "gray55", "gray40"), legend = c("ER", "RPS", "MSE", "MAE"))

graphics.off()


