###############################################################################
#                                                                             #
#   Reproducible files to 'Random Forests for Ordinal Response Data' (2014)   #
#   by Janitza, Tutz and Boulesteix                                           #
#                                                                             #
#   Contact: S. Janitza <janitza@ibe.med.uni-muenchen.de>                     #
#                                                                             #
#   File for performing simulation studies using quadratic scores             #
#                                                                             #
###############################################################################

# NOTE: running this code requires installation of R packages snowfall, party and mvtnorm

# please specify the path where the folder 'reproducible_files' is stored
path <- ""


setwd(paste(path, "reproducible_files/Simulation_Studies/R_Objects/", sep = "")) # change working directory


require(snowfall)

sfInit(parallel = TRUE, cpus = 100, type = "MPI") # if you won't do parallel computing set parallel = FALSE

sfLibrary(party)
sfLibrary(mvtnorm)
sfLibrary(ROCR)

# source the code for our novel variable importance measures
sfSource("../../novel_VIMs.R")

# source the functions implementing the simulation studies
sfSource("../R_Code/functions.R") 




# ----------------------------------------
# n = 200 (results not shown in the paper)
# ----------------------------------------


# Data generated from a mixture of two proportional odds models (cf. Eq(7) with zeta = 0.6)

simquadscores_ncat3_n200_cor <- sfSapply(1:100, function(z) perform_simulation(seed = z, scores = c(1:3)^2, ncat = 3, nobs = 200, correlations = TRUE))
save(simquadscores_ncat3_n200_cor, file = "simquadscores_ncat3_n200_cor.Rda")
rm(simquadscores_ncat3_n200_cor)

simquadscores_ncat6_n200_cor <- sfSapply(1:100, function(z) perform_simulation(seed = z, scores = c(1:6)^2, ncat = 6, nobs = 200, correlations = TRUE))
save(simquadscores_ncat6_n200_cor, file = "simquadscores_ncat6_n200_cor.Rda")
rm(simquadscores_ncat6_n200_cor)

simquadscores_ncat9_n200_cor <- sfSapply(1:100, function(z) perform_simulation(seed = z, scores = c(1:9)^2, ncat = 9, nobs = 200, correlations = TRUE))
save(simquadscores_ncat9_n200_cor, file = "simquadscores_ncat9_n200_cor.Rda")
rm(simquadscores_ncat9_n200_cor)



simquadscores_ncat3_n200_nocor <- sfSapply(1:100, function(z) perform_simulation(seed = z, scores = c(1:3)^2, ncat = 3, nobs = 200, correlations = FALSE))
save(simquadscores_ncat3_n200_nocor, file = "simquadscores_ncat3_n200_nocor.Rda")
rm(simquadscores_ncat3_n200_nocor)

simquadscores_ncat6_n200_nocor <- sfSapply(1:100, function(z) perform_simulation(seed = z, scores = c(1:6)^2, ncat = 6, nobs = 200, correlations = FALSE))
save(simquadscores_ncat6_n200_nocor, file = "simquadscores_ncat6_n200_nocor.Rda")
rm(simquadscores_ncat6_n200_nocor)

simquadscores_ncat9_n200_nocor <- sfSapply(1:100, function(z) perform_simulation(seed = z, scores = c(1:9)^2, ncat = 9, nobs = 200, correlations = FALSE))
save(simquadscores_ncat9_n200_nocor, file = "simquadscores_ncat9_n200_nocor.Rda")
rm(simquadscores_ncat9_n200_nocor)



# Data generated from a proportional odds model (1st mixture component in Eq(7), i.e. zeta = 1)

simquadscores_ncat3_n200_cor_mix1 <- sfSapply(1:100, function(z) perform_simulation(seed = z, scores = c(1:3)^2, ncat = 3, nobs = 200, correlations = TRUE, mixing = 1))
save(simquadscores_ncat3_n200_cor_mix1, file = "simquadscores_ncat3_n200_cor_mix1.Rda")
rm(simquadscores_ncat3_n200_cor_mix1)

simquadscores_ncat6_n200_cor_mix1 <- sfSapply(1:100, function(z) perform_simulation(seed = z, scores = c(1:6)^2, ncat = 6, nobs = 200, correlations = TRUE, mixing = 1))
save(simquadscores_ncat6_n200_cor_mix1, file = "simquadscores_ncat6_n200_cor_mix1.Rda")
rm(simquadscores_ncat6_n200_cor_mix1)

simquadscores_ncat9_n200_cor_mix1 <- sfSapply(1:100, function(z) perform_simulation(seed = z, scores = c(1:9)^2, ncat = 9, nobs = 200, correlations = TRUE, mixing = 1))
save(simquadscores_ncat9_n200_cor_mix1, file = "simquadscores_ncat9_n200_cor_mix1.Rda")
rm(simquadscores_ncat9_n200_cor_mix1)



simquadscores_ncat3_n200_nocor_mix1 <- sfSapply(1:100, function(z) perform_simulation(seed = z, scores = c(1:3)^2, ncat = 3, nobs = 200, correlations = FALSE, mixing = 1))
save(simquadscores_ncat3_n200_nocor_mix1, file = "simquadscores_ncat3_n200_nocor_mix1.Rda")
rm(simquadscores_ncat3_n200_nocor_mix1)

simquadscores_ncat6_n200_nocor_mix1 <- sfSapply(1:100, function(z) perform_simulation(seed = z, scores = c(1:6)^2, ncat = 6, nobs = 200, correlations = FALSE, mixing = 1))
save(simquadscores_ncat6_n200_nocor_mix1, file = "simquadscores_ncat6_n200_nocor_mix1.Rda")
rm(simquadscores_ncat6_n200_nocor_mix1)

simquadscores_ncat9_n200_nocor_mix1 <- sfSapply(1:100, function(z) perform_simulation(seed = z, scores = c(1:9)^2, ncat = 9, nobs = 200, correlations = FALSE, mixing = 1))
save(simquadscores_ncat9_n200_nocor_mix1, file = "simquadscores_ncat9_n200_nocor_mix1.Rda")
rm(simquadscores_ncat9_n200_nocor_mix1)



# Data generated from a proportional odds model (2nd mixture component in Eq(7), i.e., zeta = 0)

simquadscores_ncat3_n200_cor_mix2 <- sfSapply(1:100, function(z) perform_simulation(seed = z, scores = c(1:3)^2, ncat = 3, nobs = 200, correlations = TRUE, mixing = 0))
save(simquadscores_ncat3_n200_cor_mix2, file = "simquadscores_ncat3_n200_cor_mix2.Rda")
rm(simquadscores_ncat3_n200_cor_mix2)

simquadscores_ncat6_n200_cor_mix2 <- sfSapply(1:100, function(z) perform_simulation(seed = z, scores = c(1:6)^2, ncat = 6, nobs = 200, correlations = TRUE, mixing = 0))
save(simquadscores_ncat6_n200_cor_mix2, file = "simquadscores_ncat6_n200_cor_mix2.Rda")
rm(simquadscores_ncat6_n200_cor_mix2)

simquadscores_ncat9_n200_cor_mix2 <- sfSapply(1:100, function(z) perform_simulation(seed = z, scores = c(1:9)^2, ncat = 9, nobs = 200, correlations = TRUE, mixing = 0))
save(simquadscores_ncat9_n200_cor_mix2, file = "simquadscores_ncat9_n200_cor_mix2.Rda")
rm(simquadscores_ncat9_n200_cor_mix2)



simquadscores_ncat3_n200_nocor_mix2 <- sfSapply(1:100, function(z) perform_simulation(seed = z, scores = c(1:3)^2, ncat = 3, nobs = 200, correlations = FALSE, mixing = 0))
save(simquadscores_ncat3_n200_nocor_mix2, file = "simquadscores_ncat3_n200_nocor_mix2.Rda")
rm(simquadscores_ncat3_n200_nocor_mix2)

simquadscores_ncat6_n200_nocor_mix2 <- sfSapply(1:100, function(z) perform_simulation(seed = z, scores = c(1:6)^2, ncat = 6, nobs = 200, correlations = FALSE, mixing = 0))
save(simquadscores_ncat6_n200_nocor_mix2, file = "simquadscores_ncat6_n200_nocor_mix2.Rda")
rm(simquadscores_ncat6_n200_nocor_mix2)

simquadscores_ncat9_n200_nocor_mix2 <- sfSapply(1:100, function(z) perform_simulation(seed = z, scores = c(1:9)^2, ncat = 9, nobs = 200, correlations = FALSE, mixing = 0))
save(simquadscores_ncat9_n200_nocor_mix2, file = "simquadscores_ncat9_n200_nocor_mix2.Rda")
rm(simquadscores_ncat9_n200_nocor_mix2)



sfStop() # stop parallel mode
