###############################################################################
#                                                                             #
#   Reproducible files to 'Random Forests for Ordinal Response Data' (2014)   #
#   by Janitza, Tutz and Boulesteix                                           #
#                                                                             #
#   Contact: S. Janitza <janitza@ibe.med.uni-muenchen.de>                     #
#                                                                             #
#   File for split investigations                                             #
#                                                                             #
###############################################################################

# NOTE: running this code requires installation of R packages snowfall, party, mvtnorm and ROCR

# please specify the path where the folder 'reproducible_files' is stored
path <- ""


setwd(paste(path, "reproducible_files/Simulation_Studies/R_Objects/", sep = "")) # change working directory


require(snowfall)

sfInit(parallel = TRUE, cpus = 100, type = "MPI") # if you won't do parallel computing set parallel = FALSE

sfLibrary(party)
sfLibrary(mvtnorm)
sfLibrary(ROCR)

# source the code for our novel variable importance measures
sfSource("../../novel_VIMs.R")

# source the functions implementing the simulation studies
sfSource("../R_Code/functions_neu.R") 


# ---------------------------------------------
# n = 200 (results that are shown in the paper)
# ---------------------------------------------

# Data generated from a mixture of two proportional odds models (cf. Eq(7) with zeta = 0.6)

split_ncat3_n200_cor <- sfSapply(1:100, function(z) perform_simulation(seed = z, get.tree.fractions.only = TRUE, ncat = 3, nobs = 200, correlations = TRUE))
save(split_ncat3_n200_cor, file = "split_ncat3_n200_cor.Rda")
rm(split_ncat3_n200_cor)

split_ncat6_n200_cor <- sfSapply(1:100, function(z) perform_simulation(seed = z, get.tree.fractions.only = TRUE, ncat = 6, nobs = 200, correlations = TRUE))
save(split_ncat6_n200_cor, file = "split_ncat6_n200_cor.Rda")
rm(split_ncat6_n200_cor)

split_ncat9_n200_cor <- sfSapply(1:100, function(z) perform_simulation(seed = z, get.tree.fractions.only = TRUE, ncat = 9, nobs = 200, correlations = TRUE))
save(split_ncat9_n200_cor, file = "split_ncat9_n200_cor.Rda")
rm(split_ncat9_n200_cor)



split_ncat3_n200_nocor <- sfSapply(1:100, function(z) perform_simulation(seed = z, get.tree.fractions.only = TRUE, ncat = 3, nobs = 200, correlations = FALSE))
save(split_ncat3_n200_nocor, file = "split_ncat3_n200_nocor.Rda")
rm(split_ncat3_n200_nocor)

split_ncat6_n200_nocor <- sfSapply(1:100, function(z) perform_simulation(seed = z, get.tree.fractions.only = TRUE, ncat = 6, nobs = 200, correlations = FALSE))
save(split_ncat6_n200_nocor, file = "split_ncat6_n200_nocor.Rda")
rm(split_ncat6_n200_nocor)

split_ncat9_n200_nocor <- sfSapply(1:100, function(z) perform_simulation(seed = z, get.tree.fractions.only = TRUE, ncat = 9, nobs = 200, correlations = FALSE))
save(split_ncat9_n200_nocor, file = "split_ncat9_n200_nocor.Rda")
rm(split_ncat9_n200_nocor)



# Data generated from a proportional odds model (1st mixture component in Eq(7), i.e. zeta = 1)

split_ncat3_n200_cor_mix1 <- sfSapply(1:100, function(z) perform_simulation(seed = z, get.tree.fractions.only = TRUE, ncat = 3, nobs = 200, correlations = TRUE, mixing = 1))
save(split_ncat3_n200_cor_mix1, file = "split_ncat3_n200_cor_mix1.Rda")
rm(split_ncat3_n200_cor_mix1)

split_ncat6_n200_cor_mix1 <- sfSapply(1:100, function(z) perform_simulation(seed = z, get.tree.fractions.only = TRUE, ncat = 6, nobs = 200, correlations = TRUE, mixing = 1))
save(split_ncat6_n200_cor_mix1, file = "split_ncat6_n200_cor_mix1.Rda")
rm(split_ncat6_n200_cor_mix1)

split_ncat9_n200_cor_mix1 <- sfSapply(1:100, function(z) perform_simulation(seed = z, get.tree.fractions.only = TRUE, ncat = 9, nobs = 200, correlations = TRUE, mixing = 1))
save(split_ncat9_n200_cor_mix1, file = "split_ncat9_n200_cor_mix1.Rda")
rm(split_ncat9_n200_cor_mix1)



split_ncat3_n200_nocor_mix1 <- sfSapply(1:100, function(z) perform_simulation(seed = z, get.tree.fractions.only = TRUE, ncat = 3, nobs = 200, correlations = FALSE, mixing = 1))
save(split_ncat3_n200_nocor_mix1, file = "split_ncat3_n200_nocor_mix1.Rda")
rm(split_ncat3_n200_nocor_mix1)

split_ncat6_n200_nocor_mix1 <- sfSapply(1:100, function(z) perform_simulation(seed = z, get.tree.fractions.only = TRUE, ncat = 6, nobs = 200, correlations = FALSE, mixing = 1))
save(split_ncat6_n200_nocor_mix1, file = "split_ncat6_n200_nocor_mix1.Rda")
rm(split_ncat6_n200_nocor_mix1)

split_ncat9_n200_nocor_mix1 <- sfSapply(1:100, function(z) perform_simulation(seed = z, get.tree.fractions.only = TRUE, ncat = 9, nobs = 200, correlations = FALSE, mixing = 1))
save(split_ncat9_n200_nocor_mix1, file = "split_ncat9_n200_nocor_mix1.Rda")
rm(split_ncat9_n200_nocor_mix1)




# Data generated from a proportional odds model (2nd mixture component in Eq(7), i.e., zeta = 0)

split_ncat3_n200_cor_mix2 <- sfSapply(1:100, function(z) perform_simulation(seed = z, get.tree.fractions.only = TRUE, ncat = 3, nobs = 200, correlations = TRUE, mixing = 0))
save(split_ncat3_n200_cor_mix2, file = "split_ncat3_n200_cor_mix2.Rda")
rm(split_ncat3_n200_cor_mix2)

split_ncat6_n200_cor_mix2 <- sfSapply(1:100, function(z) perform_simulation(seed = z, get.tree.fractions.only = TRUE, ncat = 6, nobs = 200, correlations = TRUE, mixing = 0))
save(split_ncat6_n200_cor_mix2, file = "split_ncat6_n200_cor_mix2.Rda")
rm(split_ncat6_n200_cor_mix2)

split_ncat9_n200_cor_mix2 <- sfSapply(1:100, function(z) perform_simulation(seed = z, get.tree.fractions.only = TRUE, ncat = 9, nobs = 200, correlations = TRUE, mixing = 0))
save(split_ncat9_n200_cor_mix2, file = "split_ncat9_n200_cor_mix2.Rda")
rm(split_ncat9_n200_cor_mix2)



split_ncat3_n200_nocor_mix2 <- sfSapply(1:100, function(z) perform_simulation(seed = z, get.tree.fractions.only = TRUE, ncat = 3, nobs = 200, correlations = FALSE, mixing = 0))
save(split_ncat3_n200_nocor_mix2, file = "split_ncat3_n200_nocor_mix2.Rda")
rm(split_ncat3_n200_nocor_mix2)

split_ncat6_n200_nocor_mix2 <- sfSapply(1:100, function(z) perform_simulation(seed = z, get.tree.fractions.only = TRUE, ncat = 6, nobs = 200, correlations = FALSE, mixing = 0))
save(split_ncat6_n200_nocor_mix2, file = "split_ncat6_n200_nocor_mix2.Rda")
rm(split_ncat6_n200_nocor_mix2)

split_ncat9_n200_nocor_mix2 <- sfSapply(1:100, function(z) perform_simulation(seed = z, get.tree.fractions.only = TRUE, ncat = 9, nobs = 200, correlations = FALSE, mixing = 0))
save(split_ncat9_n200_nocor_mix2, file = "split_ncat9_n200_nocor_mix2.Rda")
rm(split_ncat9_n200_nocor_mix2)





# ----------------------------------------
# n = 400 (results not shown in the paper)
# ----------------------------------------

# Data generated from a mixture of two proportional odds models (cf. Eq(7) with zeta = 0.6)

split_ncat3_n400_cor <- sfSapply(1:100, function(z) perform_simulation(seed = z, get.tree.fractions.only = TRUE, ncat = 3, nobs = 400, correlations = TRUE))
save(split_ncat3_n400_cor, file = "split_ncat3_n400_cor.Rda")
rm(split_ncat3_n400_cor)

split_ncat6_n400_cor <- sfSapply(1:100, function(z) perform_simulation(seed = z, get.tree.fractions.only = TRUE, ncat = 6, nobs = 400, correlations = TRUE))
save(split_ncat6_n400_cor, file = "split_ncat6_n400_cor.Rda")
rm(split_ncat6_n400_cor)

split_ncat9_n400_cor <- sfSapply(1:100, function(z) perform_simulation(seed = z, get.tree.fractions.only = TRUE, ncat = 9, nobs = 400, correlations = TRUE))
save(split_ncat9_n400_cor, file = "split_ncat9_n400_cor.Rda")
rm(split_ncat9_n400_cor)



split_ncat3_n400_nocor <- sfSapply(1:100, function(z) perform_simulation(seed = z, get.tree.fractions.only = TRUE, ncat = 3, nobs = 400, correlations = FALSE))
save(split_ncat3_n400_nocor, file = "split_ncat3_n400_nocor.Rda")
rm(split_ncat3_n400_nocor)

split_ncat6_n400_nocor <- sfSapply(1:100, function(z) perform_simulation(seed = z, get.tree.fractions.only = TRUE, ncat = 6, nobs = 400, correlations = FALSE))
save(split_ncat6_n400_nocor, file = "split_ncat6_n400_nocor.Rda")
rm(split_ncat6_n400_nocor)

split_ncat9_n400_nocor <- sfSapply(1:100, function(z) perform_simulation(seed = z, get.tree.fractions.only = TRUE, ncat = 9, nobs = 400, correlations = FALSE))
save(split_ncat9_n400_nocor, file = "split_ncat9_n400_nocor.Rda")
rm(split_ncat9_n400_nocor)



# Data generated from a proportional odds model (1st mixture component in Eq(7), i.e. zeta = 1)

split_ncat3_n400_cor_mix1 <- sfSapply(1:100, function(z) perform_simulation(seed = z, get.tree.fractions.only = TRUE, ncat = 3, nobs = 400, correlations = TRUE, mixing = 1))
save(split_ncat3_n400_cor_mix1, file = "split_ncat3_n400_cor_mix1.Rda")
rm(split_ncat3_n400_cor_mix1)

split_ncat6_n400_cor_mix1 <- sfSapply(1:100, function(z) perform_simulation(seed = z, get.tree.fractions.only = TRUE, ncat = 6, nobs = 400, correlations = TRUE, mixing = 1))
save(split_ncat6_n400_cor_mix1, file = "split_ncat6_n400_cor_mix1.Rda")
rm(split_ncat6_n400_cor_mix1)

split_ncat9_n400_cor_mix1 <- sfSapply(1:100, function(z) perform_simulation(seed = z, get.tree.fractions.only = TRUE, ncat = 9, nobs = 400, correlations = TRUE, mixing = 1))
save(split_ncat9_n400_cor_mix1, file = "split_ncat9_n400_cor_mix1.Rda")
rm(split_ncat9_n400_cor_mix1)


split_ncat3_n400_nocor_mix1 <- sfSapply(1:100, function(z) perform_simulation(seed = z, get.tree.fractions.only = TRUE, ncat = 3, nobs = 400, correlations = FALSE, mixing = 1))
save(split_ncat3_n400_nocor_mix1, file = "split_ncat3_n400_nocor_mix1.Rda")
rm(split_ncat3_n400_nocor_mix1)

split_ncat6_n400_nocor_mix1 <- sfSapply(1:100, function(z) perform_simulation(seed = z, get.tree.fractions.only = TRUE, ncat = 6, nobs = 400, correlations = FALSE, mixing = 1))
save(split_ncat6_n400_nocor_mix1, file = "split_ncat6_n400_nocor_mix1.Rda")
rm(split_ncat6_n400_nocor_mix1)

split_ncat9_n400_nocor_mix1 <- sfSapply(1:100, function(z) perform_simulation(seed = z, get.tree.fractions.only = TRUE, ncat = 9, nobs = 400, correlations = FALSE, mixing = 1))
save(split_ncat9_n400_nocor_mix1, file = "split_ncat9_n400_nocor_mix1.Rda")
rm(split_ncat9_n400_nocor_mix1)



# Data generated from a proportional odds model (2nd mixture component in Eq(7), i.e., zeta = 0)

split_ncat3_n400_cor_mix2 <- sfSapply(1:100, function(z) perform_simulation(seed = z, get.tree.fractions.only = TRUE, ncat = 3, nobs = 400, correlations = TRUE, mixing = 0))
save(split_ncat3_n400_cor_mix2, file = "split_ncat3_n400_cor_mix2.Rda")
rm(split_ncat3_n400_cor_mix2)

split_ncat6_n400_cor_mix2 <- sfSapply(1:100, function(z) perform_simulation(seed = z, get.tree.fractions.only = TRUE, ncat = 6, nobs = 400, correlations = TRUE, mixing = 0))
save(split_ncat6_n400_cor_mix2, file = "split_ncat6_n400_cor_mix2.Rda")
rm(split_ncat6_n400_cor_mix2)

split_ncat9_n400_cor_mix2 <- sfSapply(1:100, function(z) perform_simulation(seed = z, get.tree.fractions.only = TRUE, ncat = 9, nobs = 400, correlations = TRUE, mixing = 0))
save(split_ncat9_n400_cor_mix2, file = "split_ncat9_n400_cor_mix2.Rda")
rm(split_ncat9_n400_cor_mix2)



split_ncat3_n400_nocor_mix2 <- sfSapply(1:100, function(z) perform_simulation(seed = z, get.tree.fractions.only = TRUE, ncat = 3, nobs = 400, correlations = FALSE, mixing = 0))
save(split_ncat3_n400_nocor_mix2, file = "split_ncat3_n400_nocor_mix2.Rda")
rm(split_ncat3_n400_nocor_mix2)

split_ncat6_n400_nocor_mix2 <- sfSapply(1:100, function(z) perform_simulation(seed = z, get.tree.fractions.only = TRUE, ncat = 6, nobs = 400, correlations = FALSE, mixing = 0))
save(split_ncat6_n400_nocor_mix2, file = "split_ncat6_n400_nocor_mix2.Rda")
rm(split_ncat6_n400_nocor_mix2)

split_ncat9_n400_nocor_mix2 <- sfSapply(1:100, function(z) perform_simulation(seed = z, get.tree.fractions.only = TRUE, ncat = 9, nobs = 400, correlations = FALSE, mixing = 0))
save(split_ncat9_n400_nocor_mix2, file = "split_ncat9_n400_nocor_mix2.Rda")
rm(split_ncat9_n400_nocor_mix2)



sfStop() # stop parallel mode
